#
# spec file for package python-funcparserlib
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-funcparserlib
Version:        0.3.6+repack
Release:        lp152.5.3.1
Url:            http://code.google.com/p/funcparserlib/
Summary:        Recursive descent parsing library based on functional combinators
License:        MIT
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/f/funcparserlib/funcparserlib-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-2to3
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
%if %{with tests}
BuildRequires:  %{python_module nose}
%endif
BuildArch:      noarch
%python_subpackages

%description
Parser combinators are just higher-order functions that take parsers as
their arguments and return them as result values. Parser combinators are:

First-class values. Extremely composable. Tend to make the code quite compact.
Resemble the readable notation of xBNF grammars.

Parsers made with funcparserlib are pure-Python LL(*) parsers. It means that
it's very easy to write them without thinking about look-aheads and all that
hardcore parsing stuff. But the recursive descent parsing is a rather slow
method compared to LL(k) or LR(k) algorithms.

So the primary domain for funcparserlib is parsing little languages or external
DSLs (domain specific languages).

The library itself is very small. Its source code is only 0.5 KLOC, with lots
of comments included. It features the longest parsed prefix error reporting,
as well as a tiny lexer generator for token position tracking.

%prep
%setup -q -n funcparserlib-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
pushd doc
%{python_expand export PYHONPATH=%{buildroot}%{$python_sitelib}
nosetests-%{$python_bin_suffix} -m funcparserlib
}
popd
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README CHANGES
%{python_sitelib}/funcparserlib/
%{python_sitelib}/funcparserlib*egg-info

%changelog
* Wed Feb 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Wed Feb 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Repack source tarball with non-free documentation removed
* Wed Apr 19 2017 toddrme2178@gmail.com
- Source must be https.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Sun Mar 13 2016 dmueller@suse.com
- add license
* Thu Oct 31 2013 mcihar@suse.cz
- Initial packaging
